@@ -15,9 +15,11 @@ class HttpNtlmAuth(AuthBase):
         if ntlm is None:
             raise Exception("NTLM libraries unavailable")
         #parse the username
-        user_parts = username.split('\\', 1)
-        self.domain = user_parts[0].upper()
-        self.username = user_parts[1]
+        try:
+            self.domain, self.username = username.split('\\', 1)
+        except ValueError:
+            raise ValueError("username should be in 'domain\\username' format.")
+        self.domain = self.domain.upper()
 
         self.password = password
         self.adapter = HTTPAdapter()
@@ -47,20 +49,23 @@ class HttpNtlmAuth(AuthBase):
         args_nostream = dict(args, stream=False)
         response2 = self.adapter.send(request, **args_nostream)
 
+        # needed to make NTLM auth compatible with requests-2.3.0
+        response2.content
+
         # this is important for some web applications that store authentication-related info in cookies (it took a long time to figure out)
         if response2.headers.get('set-cookie'):
             request.headers['Cookie'] = response2.headers.get('set-cookie')
 
         # get the challenge
         auth_header_value = response2.headers[auth_header_field]
-        ServerChallenge, NegotiateFlags = ntlm.parse_NTLM_CHALLENGE_MESSAGE(auth_header_value[5:])
+        ntlm_header_value = list(filter(lambda s: s.startswith('NTLM '), auth_header_value.split(',')))[0].strip()
+        ServerChallenge, NegotiateFlags = ntlm.parse_NTLM_CHALLENGE_MESSAGE(ntlm_header_value[5:])
 
         # build response
         request = copy_request(request)
         auth = 'NTLM %s' % ntlm.create_NTLM_AUTHENTICATE_MESSAGE(ServerChallenge, self.username, self.domain, self.password, NegotiateFlags)
         request.headers[auth_header] = auth
-        request.headers["Connection"] = "Close"
-
+        
         response3 = self.adapter.send(request, **args)
 
         # Update the history.
